@@ -68,6 +68,9 @@ def make_app_bundle(dist_dir, make_lite=False):
         File "<frozen zipimport>", line 177, in get_data
         KeyError: 'blib2to3/Users/rclary/Library/Caches/black/20.8b1/
         Grammar3.8.6.final.0.pickle'
+    docutils :
+        [Errno 20] Not a directory: '<path>/Resources/lib/python39.zip/
+        docutils/writers/latex2e/docutils.sty'
     ipython :
         [IPKernelApp] WARNING | Could not copy README_STARTUP to startup dir.
         Source file
@@ -140,12 +143,16 @@ def make_app_bundle(dist_dir, make_lite=False):
     build_type = 'lite' if make_lite else 'full'
     logger.info('Creating %s app bundle...', build_type)
 
-    PACKAGES = ['alabaster', 'astroid', 'blib2to3', 'IPython', 'jedi',
-                'jinja2', 'keyring', 'parso', 'pygments', 'pyls', 'pyls_black',
-                'pyls_spyder', 'qtawesome', 'setuptools', 'sphinx', 'spyder',
-                'spyder_kernels', 'textdistance',
+    PACKAGES = ['alabaster', 'astroid', 'docutils', 'blib2to3', 'IPython',
+                'jedi', 'jinja2', 'keyring', 'parso', 'pygments', 'pyls',
+                'pyls_black', 'pyls_spyder', 'qtawesome', 'setuptools',
+                'sphinx', 'spyder', 'spyder_kernels', 'textdistance',
                 ]
-    INCLUDES = ['_sitebuiltins']  # required for IPython help()
+    INCLUDES = ['_sitebuiltins',  # required for IPython help()
+                # required for sphinx
+                'sphinxcontrib.applehelp', 'sphinxcontrib.devhelp',
+                'sphinxcontrib.htmlhelp', 'sphinxcontrib.jsmath',
+                'sphinxcontrib.qthelp', 'sphinxcontrib.serializinghtml']
     EXCLUDES = []
     EXCLUDE_EGG = ['py2app']
 
@@ -163,8 +170,10 @@ def make_app_bundle(dist_dir, make_lite=False):
     EXCLUDE_EGG.extend(EXCLUDES)
     EDIT_EXT = [ext[1:] for ext in _get_extensions(EDIT_FILETYPES)]
 
-    FRAMEWORKS = ['/usr/local/lib/libspatialindex.dylib',
-                  '/usr/local/lib/libspatialindex_c.dylib']  # for rtree
+    # Get rtree dylibs
+    rtree_loc = pkg_resources.get_distribution('rtree').module_path
+    rtree_dylibs = os.scandir(os.path.join(rtree_loc, 'rtree', 'lib'))
+    FRAMEWORKS = [lib.path for lib in rtree_dylibs]
 
     OPTIONS = {
         'optimize': 0,
@@ -199,6 +208,7 @@ def make_app_bundle(dist_dir, make_lite=False):
     # Copy egg info from site-packages: fixes several pkg_resources issues
     dest_dir = os.path.join(dist_dir, MAC_APP_NAME, 'Contents', 'Resources',
                             'lib', f'python{PYVER[0]}.{PYVER[1]}')
+    pkg_resources.working_set.add_entry(SPYREPO)
     for dist in pkg_resources.working_set:
         if (dist.egg_info is None or dist.key.startswith('pyobjc')
                 or dist.key in EXCLUDE_EGG):
